<?php

namespace Drupal\glint;

use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface for the Glint service.
 */
interface GlintInterface {

  /**
   * Get main configuration for the Glint module.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   The immutable configuration object.
   */
  public function config() : ImmutableConfig;

  /**
   * Get the value of a field for a given entity.
   *
   * The output of this function is meant to be cleaner than the traditional
   * ItemList->getValue().
   *
   * @param string $fieldName
   *   Name of the field to get the value for.
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity to get the field value from.
   *
   * @return mixed
   *   The returned field value, cleaned of any noise.
   */
  public function get(string $fieldName, ContentEntityInterface $entity) : mixed;

  /**
   * Check if Preprocess File Loading is enabled in configuration.
   *
   * @return bool
   *   Returns TRUE if it's enabled, otherwise return FALSE.
   */
  public function preprocessFilesEnabled() : bool;

  /**
   * Get the directory to search for Preprocess Files in.
   *
   * This is relative to the currently active theme.
   *
   * @return string
   *   Returns the path to the configured directory in the current active theme.
   */
  public function getPreprocessFilesDirectory() : string;

  /**
   * Get the configured Preprocess Files extension.
   *
   * @return string
   *   Returns the file extension that is configured.
   */
  public function getPreprocessFilesExtension() : string;

  /**
   * Check if the configured preprocess directory exists in the active theme.
   *
   * @return bool
   *   Returns TRUE if the directory exists. Returns FALSE otherwise.
   */
  public function preprocessFilesDirectoryExistsInTheme() : bool;

}
